@@ -35,6 +35,9 @@ class Authorization(github.GithubObject.CompletableGithubObject):
     This class represents Authorizations as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"scopes": self._scopes.value})
+
     @property
     def app(self):
         """
