@@ -44,6 +44,9 @@ class Organization(github.GithubObject.CompletableGithubObject):
     This class represents Organizations. The reference can be found here http://developer.github.com/v3/orgs/
     """
 
+    def __repr__(self):
+        return self.get__repr__({"id": self._id.value, "name": self._name.value})
+
     @property
     def avatar_url(self):
         """
