@@ -36,6 +36,9 @@ class PullRequestPart(github.GithubObject.NonCompletableGithubObject):
     This class represents PullRequestParts as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"sha": self._sha.value})
+
     @property
     def label(self):
         """
