@@ -65,6 +65,9 @@ class AuthenticatedUser(Framework.TestCase):
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/jacquev6")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.user.__repr__(), 'AuthenticatedUser(login="jacquev6")')
+
     def testEditWithoutArguments(self):
         self.user.edit()
 
